<TS language="he" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>יצירת כתובת חדשה</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>העתקת הכתובת המסומנת ללוח הגזירים</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתקה</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>מחיקת הכתובת שנבחרה מהרשימה</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>מ&amp;חיקה</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>העתק &amp;תוית</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ערוך</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>תוית</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>כתובת</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ללא תוית)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>דו־שיח מילת צופן</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>נא להזין מילת צופן</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>מילת צופן חדשה</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>נא לחזור על מילת הצופן החדשה</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>ארנק</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;סקירה</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>הצגת סקירה כללית של הארנק</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;שליחה</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;קבלה</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>עיון בהיסטוריית ההעברות</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>יציאה מהתכנית</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;אפשרויות…</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>ה&amp;צגה / הסתרה</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>ה&amp;צפנת הארנק…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>ה&amp;חלפת מילת הצופן…</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>החלפת מילת הצופן להצפנת הארנק</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;חתימה על הודעה…</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;אימות הודעה…</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>חלון &amp;ניפוי</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>פתיחת לוח הבקרה לאבחון ולניפוי</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>ה&amp;גדרות</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ע&amp;זרה</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>עדכני</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>מתבצע עדכון…</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>העברת שליחה</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>העברת קבלה</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>הארנק &lt;b&gt;מוצפן&lt;/b&gt; ו&lt;b&gt;נעול&lt;/b&gt; כרגע</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>כמות:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>בתים:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>סכום:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>עמלה:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>לאחר עמלה:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>עודף:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>כמות</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>תאריך</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>אישורים</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>מאושר</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ללא תוית)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>עריכת כתובת</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>ת&amp;ווית</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;כתובת</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;ראשי</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;רשת</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>מיפוי פתחה באמצעות UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;פתחה:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>הפתחה של המתווך (למשל 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;חלון</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>הצג סמל מגש בלבד לאחר מזעור החלון.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>מ&amp;זעור למגש במקום לשורת המשימות</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>מ&amp;זעור עם סגירה</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>ת&amp;צוגה</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;שפת מנשק המשתמש:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>י&amp;חידת מידה להצגת כמויות:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>ניתן לבחור את בררת המחדל ליחידת החלוקה שתוצג במנשק ובעת שליחת מטבעות.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;אישור</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;ביטול</translation>
    </message>
    <message>
        <source>default</source>
        <translation>בררת מחדל</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>כתובת המתווך שסופקה אינה תקינה.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>זמין:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>היתרה הזמינה הנוכחית</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>לא בשל:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>סך הכול:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>סך כל היתרה הנוכחית שלך</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>גרסת מנשק</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>מי&amp;דע</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>זמן עלייה</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>מספר חיבורים</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>שרשרת מקטעים</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>מספר המקטעים הנוכחי</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>זמן המקטע האחרון</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;פתיחה</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;ניקוי</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>מ&amp;סוף בקרה</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;תעבורת רשת</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>סכומים</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>נכנס:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>יוצא:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>קובץ יומן ניפוי</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>ניקוי מסוף הבקרה</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>יש להשתמש בחצים למעלה ולמטה כדי לנווט בהיסטוריה, וב־&lt;b&gt;Ctrl-L&lt;/b&gt; כדי לנקות את המסך.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>ניתן להקליד &lt;b&gt;help&lt;/b&gt; לקבלת סקירה של הפקודות הזמינות.</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 ב׳</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 ק״ב</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 מ״ב</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 ג״ב</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>שליחת מטבעות</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>קלטים…</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>בבחירה אוטומטית</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>אין מספיק כספים!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>כמות:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>בתים:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>סכום:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>עמלה:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>לאחר עמלה:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>שליחה למספר מוטבים בו־זמנית</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>הוספת &amp;מוטב</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;ניקוי הכול</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>אישור פעולת השליחה</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;שליחה</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ללא תוית)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;כמות:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>לשלם ל&amp;טובת:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>הודעה:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>ת&amp;ווית:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>הדבקת כתובת מלוח הגזירים</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>חתימות - חתימה או אימות של הודעה</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>חתימה על הו&amp;דעה</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>הדבקת כתובת מלוח הגזירים</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>יש להוסיף כאן את ההודעה עליה לחתום</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>העתקת החתימה הנוכחית ללוח הגזירים</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>&amp;חתימה על הודעה</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>איפוס כל שדות החתימה על הודעה</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>&amp;ניקוי הכול</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;אימות הודעה</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>איפוס כל שדות אימות ההודעה</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>חלונית זו מציגה תיאור מפורט של ההעברה</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Label</source>
        <translation>תוית</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>כתובת</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>האזנה נכשלה בכל פורט. השתמש ב- -listen=0 אם ברצונך בכך.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>כתובת ‎-proxy לא תקינה: '%s'</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>הכתובות בטעינה…</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>רשת לא ידועה צוינה דרך ‎-onlynet:‏ '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>אין מספיק כספים</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>מפתח המקטעים נטען…</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>הארנק בטעינה…</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>לא ניתן לכתוב את כתובת בררת המחדל</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>סריקה מחדש…</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>טעינה הושלמה</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
</TS>